// --- [ main.c ] --------------------------------------------------------------
//       tab = 3
//
//      Temperaturmessung mit 1-Wire-Bus / Sensoren DS18B20 (ROM-SEARCH-free)
//
//      Die Sensoren sind nicht ber einen Bus sondern einzeln an den Pins des Controllers
//      angeschlossen.
//      Jeder DQ-Pin bentigt einen Pullup nach VCC.
//      Der Vorteil dieser Lsung: 
//      Die ROM-Codes der Sensoren mssen nicht bekannt sein.
//      Jeder Sensor wird einzeln und nacheinder mit einem "SKIP ROM" angesprochen
//      und anschlieend die Temperatur ausgelesen.
//      Das funktioniert deshalb, weil nie mehr als 1 Sensor an jedem Pin angeschlossen ist.
//      
// ----------------------------------------------------------------------------

#define EXTERN

#include <avr/io.h>
#include <avr/interrupt.h>
#include <inttypes.h>
#include <stdlib.h>
#include <util/delay.h>
#include <stdio.h>
#include "rs232_mini.h"
#include "owi_lib_sx.h"
#include "global.h"
#include "utility.h"

// ----------------------------------------------------------------------------
int main(void)
{
uint8_t i, sensor_mask;
int16_t tt;

ONE_WIRE_PORT_CONFIG;							// DQ-Pins auf HIGH ziehen

// --- die Serielle Schnittstelle aktivieren
RS232_Init();

put_c(13);
put_s("Port: 0x");
put_s(utoa(ONE_WIRE_PORT, cv, 16));
put_s(" PinMaske: 0x");
put_s(utoa(ONE_WIRE_PIN_MASK, cv, 16));
put_c(13);

while(1)												// Hauptschleife
	{
	OW_convert(ONE_WIRE_PIN_MASK);			// an alle Sensoren ein CONVERT senden
	
	delay_10ms(80);								// 800ms warten
	
	sensor_mask = 1;								// Achtung, hier die Pinmaske richtig whlen !!
	for(i = 0; i < 8; i++)						// Alle 8 Pins abfragen
	{
		if (ONE_WIRE_PIN_MASK & sensor_mask)// aber nur dann, wenn der Pin als Anschluss fr DQ definiert ist  
		{
			tt = DS18B20_read(sensor_mask);		// Wert als int16 abholen
			itoa(tt, cv, 10);							// in einen String umwandeln
			Make_Dez_Point1();						// einen Dezimalpunkt einschmuggeln
			put_s(cv);									// den String ausgeben
			put_c(DELIMITER);
		}	
		sensor_mask *= 2;							// Maskierten Pin weiterschieben
	}
	put_c(13);
	delay_10ms(200);								// 2 Sekunden Wartezeit
	}
}

// --- [ eof ] ----------------------------------------------------------------