// --- [owi_lib_s.h ] -----------------------------------------------------------
//
//      Lib zum ansprechen von mehreren Sensoren, bei denen jeweils der DQ-Pin
//      an einem eigenen Portpin angeschlossen ist.
//      Zur Vereinfachung - weil in der Regel ausreichend - sind alle DQ-Pins
//      an gleichen Port angeschlossen, somit knnen bis zu 8 Sensoren ausgelesen werden

#define ONE_WIRE_PORT		PORTC		// Den Port fr die DQ-Pins festlegen
#define ONE_WIRE_PIN			PINC
#define ONE_WIRE_DDR			DDRC
												// Festlegen, welche Pins benutzt werden sollen
												// PC6 = Reset, PC7 gibt am ATMegax8 nicht !
#define ONE_WIRE_PIN_MASK	(1<<PC5 | 1<<PC4 | 1<<PC3 | 1<<PC2 | 1<<PC1 | 1<<PC0)

// Die Pins fr DQ als Ausgang schalten und auf HIGH legen
#define ONE_WIRE_PORT_CONFIG	(ONE_WIRE_DDR  |= ONE_WIRE_PIN_MASK); \
                              (ONE_WIRE_PORT |= ONE_WIRE_PIN_MASK)

#define DQ_LOW					ONE_WIRE_PORT &= ~(ow_pin_mask)
#define DQ_HIGH				ONE_WIRE_PORT |=  (ow_pin_mask)
#define DQ_OUTPUT				ONE_WIRE_DDR  |=  (ow_pin_mask)
#define DQ_INPUT				ONE_WIRE_DDR  &= ~(ow_pin_mask)
#define DQ_READ				ONE_WIRE_PIN  &   (ow_pin_mask)


#define SEARCH_ROM			0xF0
#define READ_ROM				0x33
#define MATCH_ROM				0x55
#define SKIP_ROM				0xCC
#define ALARM_SEARCH			0xEC
#define CONVERT				0x44
#define WRITE_SCRATCHPAD	0x4E
#define READ_SCRATCHPAD		0xBE
#define COPY_SCRATCHPAD		0x48
#define RECALL_E				0xB8
#define READ_POWER_SUPPLY	0xB4

#define DS18B20				0x28			// Family-Code fr DS18B20

#define DELAY_A				6				// Wartezeiten gem. APP-NOTE 126, Page 2-3
#define DELAY_B				64				// fr Standard Speed
#define DELAY_C				60
#define DELAY_D				10
#define DELAY_E				9
#define DELAY_F				55
#define DELAY_G				1				// anstelle 0
#define DELAY_H				480
#define DELAY_I				70
#define DELAY_J				410

// --- public Funktionen ------------------------------------------------------

void    OW_convert(uint8_t mask);
int16_t DS18B20_read(uint8_t mask);

// --- [ eof ] ----------------------------------------------------------------